@@ -81,7 +81,7 @@ class ItemEditorResource(XSLForms.Resources.WebResources.XSLFormsResource):
         # Get useful information about the request.
 
         pvpath = trans.get_processed_virtual_path_info(self.path_encoding)
-        parent_path = trans.update_path(pvpath, "")
+        parent_path = trans.get_path_without_info(self.path_encoding) + trans.update_path(pvpath, "")
 
         # Determine which item is being edited.
         # The item type can be advisory since this may be a new item where we
