@@ -22,7 +22,6 @@ If not, write to the Free Software Foundation, Inc.,
 """
 
 from WebStack.Generic import ContentType, EndOfResponse
-import RDFCalendar.Parsers
 import urllib
 import codecs
 import os
@@ -43,7 +42,7 @@ class ItemImporterResource:
         # Get the name and type of the file.
 
         attributes = trans.get_attributes()
-        item_type_name = attributes["item-type"]
+        item_type = attributes["item-type"]
         item_value = attributes["item-value"]
 
         # NOTE: Assuming UTF-8 input. Check the actual uploaded data!
@@ -65,17 +64,17 @@ class ItemImporterResource:
                 # was not doubly-encoded and contains characters outside the
                 # ASCII subset.
 
-                uriref = self.store.get_item_from_identifier(urllib.quote(item_value))
+                uriref = self.store.get_item_from_identifier(urllib.quote(item_value).replace("/", "%2F").replace("#", "%23"))
 
                 # Read the uploaded data.
 
                 try:
-                    RDFCalendar.Parsers.parse(in_stream, self.store.cstore, name=item_value, uriref=uriref)
+                    self.store.parse_item(in_stream, item_type, uriref=uriref)
                     self.store.commit()
                     trans.set_response_code(201)
-                except RDFCalendar.Parsers.DuplicateResourceError:
+                except self.store.DuplicateResourceError:
                     self.store.remove_item(uriref)
-                    RDFCalendar.Parsers.parse(in_stream, self.store.cstore, name=item_value, uriref=uriref)
+                    self.store.parse_item(in_stream, item_type, uriref=uriref)
                     self.store.commit()
                     trans.set_response_code(200)
 
