@@ -64,6 +64,7 @@ class CalendarViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         # redirect to new resource editors.
 
         pvpath = trans.get_processed_virtual_path_info(self.path_encoding)
+        ppath = trans.get_path_without_info(self.path_encoding) + pvpath
 
         # Get the items in the form.
 
@@ -95,7 +96,7 @@ class CalendarViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
         elif parameters.has_key("new"):
             new_type = items.xpath("items/new-type/@value")[0].nodeValue
-            new_path = trans.update_path(pvpath, "../%s/new/" % new_type)
+            new_path = trans.update_path(ppath, "../%s/new/" % new_type)
             trans.redirect(trans.encode_path(new_path, self.path_encoding))
             # Response ended!
 
@@ -194,6 +195,7 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         # redirect to new resource editors.
 
         pvpath = trans.get_processed_virtual_path_info(self.path_encoding)
+        ppath = trans.get_path_without_info(self.path_encoding) + pvpath
 
         # Get the items in the form.
 
@@ -252,7 +254,7 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
         elif parameters.has_key("new"):
             new_type = items.xpath("items/new-type/@value")[0].nodeValue
-            new_path = trans.update_path(pvpath, "../%s/new/" % new_type)
+            new_path = trans.update_path(ppath, "../%s/new/" % new_type)
             trans.redirect(trans.encode_path(new_path, self.path_encoding))
             # Response ended!
 
@@ -345,7 +347,9 @@ class PropertyViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         # Get the processed path details and a version suitable for output.
 
         pvpath = trans.get_processed_virtual_path_info(self.path_encoding)
+        ppath = trans.get_path_without_info(self.path_encoding) + pvpath
         encoded_pvpath = "/".join([trans.encode_path(part, self.path_encoding) for part in pvpath.split("/")])
+        encoded_ppath = trans.get_path_without_info(self.path_encoding) + encoded_pvpath
 
         # Obtain information relevant to the item search.
 
@@ -413,7 +417,7 @@ class PropertyViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         # Define the stylesheet parameters.
 
         stylesheet_parameters = {
-            "path" : trans.get_path_without_info() + encoded_pvpath
+            "path" : encoded_ppath
             }
         stylesheet_parameters["root"] = attributes["root"]
 
@@ -448,7 +452,9 @@ class SimpleViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         # Get the processed path details and a version suitable for output.
 
         pvpath = trans.get_processed_virtual_path_info(self.path_encoding)
+        ppath = trans.get_path_without_info(self.path_encoding) + pvpath
         encoded_pvpath = "/".join([trans.encode_path(part, self.path_encoding) for part in pvpath.split("/")])
+        encoded_ppath = trans.get_path_without_info(self.path_encoding) + encoded_pvpath
 
         # Invent a document based on the resources.
 
@@ -470,7 +476,7 @@ class SimpleViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         # Define the stylesheet parameters.
 
         stylesheet_parameters = {
-            "path" : trans.get_path_without_info() + encoded_pvpath
+            "path" : encoded_ppath
             }
         stylesheet_parameters["root"] = attributes["root"]
 
